/*
 * Super simple slideshows with any type of elements.
 * Apply to an element with multiple absolutely positioned child elements.
 */
(function($) { $.fn.slides = (function(options) {

    /* Default options. */
    options = $.extend({
        fade:     200,           // Speed of crossfade.
        speed:    2000,          // Duration of each slide.
        pager:    false,         // Create pager elements in this selector.
        play:     true,          // Autoplay slideshow.
        numbers:  false,         // Add numbers to pagination links.
        active:   "activeSlide"  // Class to add to active pagination link.
    }, options);

    var slides, timer, play, pause, next, select, pager, page;

    /* Start timed fading of slides. */
    play = function() {
        if(!options.play) return;
        clearInterval(timer);
        timer = setInterval(next, options.speed, slides);
    };

    /* Pause running the slideshow. */
    pause = function() {
        if(!options.play) return;
        clearInterval(timer);
    };

    /* Go to next slide. */
    next = function() {
        var n = $(slides).not(":hidden").fadeOut(options.fade).next();
        ((n.length === 0) ? slides.first() : n).fadeIn(options.fade);
        page();
    };

    /* Go to previous slide. */
    prev = function() {
        var n = $(slides).not(":hidden").fadeOut(options.fade).prev();
        ((n.length === 0) ? slides.last() : n).fadeIn(options.fade);
        page();
    };

    /* Select one slide. */
    select = function(slide, page) {
        return function(event) {
            event.preventDefault();
            var current = $(slides).not(":hidden");
            if($(current).get(0) !== $(slide).get(0)) {
                current.fadeOut(options.fade);
                $(slide).fadeIn(options.fade);
            }
            play();
            if(page) {
                $(options.pager).children().removeClass(options.active);
                $(page).addClass(options.active);
            }
        };
    };

    /* Create pagination links. */
    pager = function() {
        if(!options.pager) return;
        $(slides).map(function(i, s) {
            var num = options.numbers ? "" + i : "";
            var link = $("<a />").attr("href", "#").text(num);
            $(link).on("click", select(s, link));
            $(options.pager).append(link);
        });
        $(options.pager).children().first().addClass(options.active);
        $(options.pager).fadeIn("fast");
    };

    /* Set to next pager element. */
    page = function() {
        if(!options.pager) return;
        var p = $(options.pager).children();
        var n = $(options.pager).find("." + options.active).next();
        p.removeClass(options.active);
        ((n.length === 0) ? p.first() : n).addClass(options.active);
    };

    return this.each(function() {
        slides = $(this).children();
        $(slides).hide().first().show();
        $(slides).on("click", function() { next(); play(); });
        $(slides).hover(pause, play);
        pager();
        play();
    });

}); }($));