/*global $ */

/**
 * Simple Tabbed Boxes with jQuery
 * 
 * JS:
 * $(document).ready(function() {
 *   $('.tabs').tabBox('.tabs', 'active');
 * });
 * 
 * HTML:
 * <ul class="tabs">
 *   <li><a href="http://example.com" rel="tab1" class="active">first tab</a></li>
 *   <li><a href="http://example.com" rel="tab2">second tab</a></li>
 *   <li><a href="http://example.com" rel="tab3">third tab</a></li>
 * </ul>
 * <div id="tab1">first tab content</div>
 * <div id="tab2" class="hide">second tab content</div>
 * <div id="tab3" class="hide">third tab content</div>
 *
 * CSS:
 * .hide { display:none; }
 * .active { font-weight:bold; }
 * 
 */

$.fn.tabBox = function(groupSelector, activeClass) {
    
    // get content based on link's rel attr
    var content = function(link) {
        return $('#' + $(link).attr('rel'));
    };

    this.find('a').click(function() { 
        
        // find all tabs in this group
        var links = $(this).parents(groupSelector).find('a'); 
          
        // hide all content related to this tab group
        links.each(function() {
            content(this).hide();
        });
        
        // show new content
        content(this).show();
        
        // select the new tab as active
        links.removeClass(activeClass);
        $(this).addClass(activeClass);
        
        this.blur();
        return false;
    });
};